@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 14442 2010-09-22 07:40:40Z mjevans $
+# $Id: ODBC.pm 14569 2010-12-14 16:20:49Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -19,7 +19,7 @@ require 5.006;
 # see discussion on dbi-users at
 # http://www.nntp.perl.org/group/perl.dbi.dev/2010/07/msg6096.html and
 # http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-$DBD::ODBC::VERSION = '1.25';
+$DBD::ODBC::VERSION = '1.27';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -32,7 +32,7 @@ $DBD::ODBC::VERSION = '1.25';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 14442 2010-09-22 07:40:40Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 14569 2010-12-14 16:20:49Z mjevans $, 13,2);
 
     require_version DBI 1.21;
 
@@ -370,16 +370,14 @@ $DBD::ODBC::VERSION = '1.25';
         ## no critic (ProhibitMagicNumbers)
         if( -1 == $#params )
         {
-          # No parameters, use execute immediate
-          $rows = ExecDirect( $dbh, $statement );
-          if( 0 == $rows )
-          {
-              $rows = "0E0";    # 0 but true
-          }
-          elsif( $rows < -1 )
-          {
-              undef $rows;
-          }
+            $dbh->STORE(Statement => $statement);
+            # No parameters, use execute immediate
+            $rows = ExecDirect( $dbh, $statement );
+            if( 0 == $rows ) {
+                $rows = "0E0";    # 0 but true
+            } elsif( $rows < -1 ) {
+                undef $rows;
+            }
         }
         else
         {
@@ -526,7 +524,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.25.
+This documentation refers to DBD::ODBC version 1.27.
 
 =head1 SYNOPSIS
 
@@ -1367,7 +1365,11 @@ a named placeholder is not ignored and should be see
 L</odbc_ignore_named_placeholders> for a workaround and mail me an
 example along with your ODBC driver name.
 
-=head2 do
+=head3 do
+
+This is not really a deviation from the DBI specification since DBI
+allows a driver to avoid the overhead of creating an DBI statement
+handle for do().
 
 DBD::ODBC implements C<do> by calling SQLExecDirect in ODBC and not
 SQLPrepare followed by SQLExecute so C<do> is not the same as:
@@ -1381,6 +1383,11 @@ backup) as the procedure may not complete. See the DBD::ODBC FAQ and
 in general you are better to use prepare/execute when calling
 procedures.
 
+In addition, you should realise that since DBD::ODBC does not create a
+DBI statement for do calls, if you set up an error handler the handle
+passed in when a do fails will be the database handle and not
+a statement handle.
+
 =head3 Mixed placeholder types
 
 There are 3 conventions for place holders in DBI. These are '?', ':N'
